#
# spec file for package gnonograms
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gnonograms
Version:        2.0.0
Release:        1.8
Summary:        Program for creating and solving gnonogram puzzles
License:        GPL-3.0-or-later
Group:          Amusements/Games/Logic
URL:            https://github.com/jeremypw
Source:         https://github.com/jeremypw/gnonograms/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Patch0:         gnonograms-meson-0.61.patch
BuildRequires:  AppStream
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  libxml2-tools
BuildRequires:  meson >= 0.40.0
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  vala
BuildRequires:  pkgconfig(gee-0.8)
BuildRequires:  pkgconfig(granite) >= 5.2.0
BuildRequires:  pkgconfig(gtk+-3.0) > 3.22.0
BuildRequires:  pkgconfig(libhandy-1)

%description
An implementation of the Japanese logic puzzle "Nonograms".

%lang_package

%prep
%autosetup -p1

%build
%meson
%meson_build

%install
%meson_install

find %{buildroot} -name com.github.jeremypw.gnonograms-extra.mo -exec rm {} +

%suse_update_desktop_file -r com.github.jeremypw.gnonograms GTK Game LogicGame
%find_lang com.github.jeremypw.gnonograms %{name}.lang
%fdupes %{buildroot}/%{_datadir}

%files
%license LICENSE
%doc README.md
%{_bindir}/com.github.jeremypw.gnonograms
%{_datadir}/metainfo/com.github.jeremypw.gnonograms.appdata.xml
%{_datadir}/applications/com.github.jeremypw.gnonograms.desktop
%dir %{_datadir}/icons/hicolor/*@2
%dir %{_datadir}/icons/hicolor/*@2/apps
%{_datadir}/icons/hicolor/*/*/*.??g
%{_datadir}/glib-2.0/schemas/com.github.jeremypw.gnonograms.gschema.xml

%files lang -f %{name}.lang

%changelog
* Thu Mar  3 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 2.0.0:
  + Restyled headerbar
  + New app icon
  + Responds to user's prefers-dark setting
  + Updated translations.
- Add pkgconfig(libhandy-1) BuildRequires: new dependency.
- Add gnonograms-meson-0.61.patch: Fix build with meson 0.61.
* Wed Sep  9 2020 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.4.5:
  * Dutch translation - thanks to Heimen Stoffels
  * Portuguese translation - thanks to André Barata
* Mon Dec 23 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.4.3:
  * Revert separate library; compile core into executable
* Mon Nov 25 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.4.2:
  * French translations
  * Redesigned headerbar
  * Use separate gnonograms library
  * Commandline options
  * Fix CI and testing
  * Minor bug fixes
  * Code cleanup
* Mon Nov 18 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.4.0:
  * New screenshots
  * Add release notes
  * Replace missing icons
  * Further work on headerbar
  * Start reworking headerbar
  * Improve ScaleGrid setting
  * Ensure non-null game name.
  * Fix binding flag regression
  * Fix long lines.
  * Import changes to appdata.xml and data/meson.build from
    NathanBmn
  * Make post_install.py executable
  * Change the way to test
  * New attempt
  * Attempt to fix build
  * Fix missing )
  * Fix build
  * Remove incorrect language files
  * Regenerate all po files except fr.po from scratch to remove
    extraneous material
  * Update fr.po
  * Merge pull request #28 from NathanBnm/master
  * Merge pull request #27 from jeremypw/update-po
  * Update po files
  * Merge pull request #26 from jeremypw/update-pot
  * Update POTFILES and .pot files
  * Bump some dependencies
  * ...
- Add new package with shared library
* Sat Sep  1 2018 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.3.0:
  * Add release 1.3 appdata
  * Fix new appdata issues
  * Specify env in travis.yml
  * Stop appdata validation failing with pedantic
  * Ignore debian folder
  * Fix appdata id field
  * Add OARS content rating
  * Remove debian folder to orphan branches
  * Fix variable naming convention deviations
  * Fix vala-lint errors
  * Change static constants to const
  * Remove unused constants
  * Convert to Gtk.Application
  * Remove Gnonograms_ from source file names.
  * Rename gnonograms.vala to Application.vala as per elementary
    convention
  * Fix lint found by vala-lint; consistent { get; set; } style.
  * Fix README.md typo
* Sat Jul 28 2018 jengelh@inai.de
- Use noun phrase in summary.
* Fri Jun 15 2018 avvissu@yandex.by
- Initial package
